@@ -20,7 +20,7 @@ from lesscode.db.connection_info import ConnectionInfo
 from lesscode.db.es.es_pool import EsPool
 from lesscode.db.es.es_request import EsRequest
 from lesscode.db.page import Page
-from lesscode.utils.EsUtil import format_es_param_result, correction_query, es_mapping2dict
+from lesscode.utils.EsUtil import format_es_param_result,  es_mapping2dict
 from lesscode.utils.common import dict2single_dict
 from lesscode.utils.encryption_algorithm import AES
 
